@@ -645,8 +645,8 @@ map.feature <- function(languages,
       stroke = FALSE,
       radius = stroke.radius * 1.15,
       fillOpacity = stroke.opacity,
-      color = "black"
-    ) %>%
+      color = "black",
+      group = mapfeat.stroke$control) %>%
       leaflet::addCircleMarkers(
         lng = mapfeat.stroke$long,
         lat = mapfeat.stroke$lat,
@@ -656,8 +656,7 @@ map.feature <- function(languages,
         radius = stroke.radius,
         fillOpacity = stroke.opacity,
         color = stroke.pal(mapfeat.stroke$stroke.features),
-        group = mapfeat.stroke$stroke.features
-      ) %>%
+        group = mapfeat.stroke$control) %>%
       leaflet::addCircleMarkers(
         lng = mapfeat.stroke$long,
         lat = mapfeat.stroke$lat,
@@ -669,14 +668,12 @@ map.feature <- function(languages,
           offset = c(label.fsize*offset/2, 0),
           textOnly = TRUE,
           style = list("font-size" = paste0(label.fsize, "px"),
-                       "font-family" = label.font)
-        ),
+                       "font-family" = label.font)),
         stroke = FALSE,
         radius = 1.15 * width,
         fillOpacity = opacity,
         color = rev.stroke.pal(mapfeat.stroke$stroke.features),
-        group = mapfeat.stroke$stroke.features
-      )
+        group = mapfeat.stroke$control)
   }
 
   # map: add points ----------------------------------------
@@ -788,6 +785,7 @@ map.feature <- function(languages,
       opacity = 0,
       clusterOptions = point.cluster,
       fillOpacity = 0,
+      group = mapfeat.df$control,
       labelOptions = leaflet::labelOptions(
         noHide = TRUE,
         textOnly = TRUE,
@@ -939,7 +937,6 @@ map.feature <- function(languages,
     m <- m %>% leaflet::addScaleBar(position = scale.bar.position)
   }
 
-
   # map: legend -------------------------------------------------------------
   if (sum(mapfeat.df$features == "") < length(mapfeat.df$features) &
       legend == TRUE &
